![Github All Releases](https://img.shields.io/github/downloads/casadi/casadi/total.svg)

Learn all about CasADi at the [homepage](http://casadi.org) or jump to [install instructions](http://install.casadi.org)...
